#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-language-server
version:              2.2.0.0
visibility:           public
id:                   haskell-language-server-2.2.0.0-EVEZua6wyLc517uu2QWzSs
key:                  haskell-language-server-2.2.0.0-EVEZua6wyLc517uu2QWzSs
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             LSP server for GHC
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  8c04ad2e49ab2937c742eb387ee7408f
exposed:              True
exposed-modules:      HlsPlugins Ide.Arguments Ide.Main Ide.Version
hidden-modules:       Paths_haskell_language_server
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.2.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.2.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.2.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-server
hs-libraries:         HShaskell-language-server-2.2.0.0-EVEZua6wyLc517uu2QWzSs
depends:
    aeson-pretty-0.8.10-FzerwUFuCwVFAzZJsDIw6C
    async-2.2.5-Jzg6PXAbUPTGsNolvwhTll base-4.18.2.1
    base16-bytestring-1.0.2.0-H68TCw35DEF67v5ehYoI5v
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-AQ411u3Q3iI1te8wctwZRM
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    extra-1.7.16-5wibn5p3dDHK0RAEHmHjOt filepath-1.4.300.1 ghc-9.6.6
    ghcide-2.2.0.0-LTYSQCPFpXhKThfiL7WDD7
    githash-0.1.6.3-1JyXYMar7rjGloM4cWq5M9
    hie-bios-0.12.0-2TRjSvGJ74g6GoTEMeSP0l
    hiedb-0.4.3.0-5Wb6U7OoC3TJVHk3JRwuaa
    hls-alternate-number-format-plugin-2.2.0.0-2hKVK8jLIbQIuZFM3vDmH4
    hls-cabal-fmt-plugin-2.2.0.0-IP1zNvnRiC4EkHJTMKZJ7s
    hls-cabal-plugin-2.2.0.0-QixT0fOHY777pR1qEPO0o
    hls-call-hierarchy-plugin-2.2.0.0-Cuo4RpAZMt6vuGJSxNL1A
    hls-change-type-signature-plugin-2.2.0.0-1KBJXRCxe9DCj5biIEPp8j
    hls-class-plugin-2.2.0.0-J2WhZmq5uOcSJCpoMCnVQ
    hls-code-range-plugin-2.2.0.0-3kzyjOWQCaSHATlv6AZl0V
    hls-eval-plugin-2.2.0.0-DNI4BA4SB1a1CIV7LjNkUa
    hls-explicit-fixity-plugin-2.2.0.0-BQPQ6VwK5VSCv7EyKi4MXI
    hls-explicit-imports-plugin-2.2.0.0-Kr9gS5nrN2pFiG37lecLHo
    hls-explicit-record-fields-plugin-2.2.0.0-1sglxXm1BEBDYJXJS9pS8q
    hls-fourmolu-plugin-2.2.0.0-GDeVzvCN8D3AFtVkfjPATB
    hls-gadt-plugin-2.2.0.0-5RV4UajODQK1ZlHCtR3PuI
    hls-graph-2.2.0.0-EO2rRxTzGr690z8m8DYAMt
    hls-hlint-plugin-2.2.0.0-6sx8vSJVUS9EhDPLjej6cs
    hls-module-name-plugin-2.2.0.0-8jrhJDhIqgZ8YZdnqs5Q0U
    hls-ormolu-plugin-2.2.0.0-KZNwSssR7wp4oI1qmLIrPV
    hls-overloaded-record-dot-plugin-2.2.0.0-8DZdPjq6po1D1MBb8OMAT4
    hls-plugin-api-2.2.0.0-8GCb8iO3kpmLV9RcpzJ7mb
    hls-pragmas-plugin-2.2.0.0-9lmICmUcsxFHbnbKWO4xpU
    hls-qualify-imported-names-plugin-2.2.0.0-GQD5dlHIA6qRehLI2ompo
    hls-refactor-plugin-2.2.0.0-9X6DcnN8MClK26ulmIfrO8
    hls-rename-plugin-2.2.0.0-5tvCtXVXHjC5PM2q8BN17R
    hls-retrie-plugin-2.2.0.0-LAqWl8gMbdFKxh5lxq6w8f
    hls-splice-plugin-2.2.0.0-A9g6l5C17COCVHzpxkYMKn
    hls-stylish-haskell-plugin-2.2.0.0-C834rs6kHfzUFmBHgqPgi
    lsp-2.2.0.0-eMvV3FRX9gCFGO6PEmJjh
    optparse-applicative-0.18.1.0-ImROGgSnUkvGvLupUIrfSI
    optparse-simple-0.1.1.4-5FmAmA5Nr919Llj7tJer9N
    prettyprinter-1.7.1-Du8XnOZ5nvL2FdTwmHe7nl process-1.6.19.0
    safe-exceptions-0.1.7.4-Ln6YfNorjdbD1HCSMJxahE
    sqlite-simple-0.4.19.0-BeMrmjiRQgCF8dc3ZPno8b text-2.0.2
    unordered-containers-0.2.20.1-C4c13QuwLgs7TJHWi6VHCN

haddock-interfaces:
    /usr/share/doc/haskell-language-server/html/haskell-language-server.haddock

haddock-html:         /usr/share/doc/haskell-language-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

